from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.judge import result_pb2 as _result_pb2
from eolymp.judge import score_pb2 as _score_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DescribeScoreInput(_message.Message):
    __slots__ = ["contest_id", "mode", "participant_id", "time_offset"]
    CONTEST_ID_FIELD_NUMBER: _ClassVar[int]
    MODE_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANT_ID_FIELD_NUMBER: _ClassVar[int]
    TIME_OFFSET_FIELD_NUMBER: _ClassVar[int]
    contest_id: str
    mode: _score_pb2.Score.FetchingMode
    participant_id: str
    time_offset: int
    def __init__(self, contest_id: _Optional[str] = ..., participant_id: _Optional[str] = ..., mode: _Optional[_Union[_score_pb2.Score.FetchingMode, str]] = ..., time_offset: _Optional[int] = ...) -> None: ...

class DescribeScoreOutput(_message.Message):
    __slots__ = ["score"]
    SCORE_FIELD_NUMBER: _ClassVar[int]
    score: _score_pb2.Score
    def __init__(self, score: _Optional[_Union[_score_pb2.Score, _Mapping]] = ...) -> None: ...

class ExportResultInput(_message.Message):
    __slots__ = ["contest_id", "mode", "time_offset"]
    CONTEST_ID_FIELD_NUMBER: _ClassVar[int]
    MODE_FIELD_NUMBER: _ClassVar[int]
    TIME_OFFSET_FIELD_NUMBER: _ClassVar[int]
    contest_id: str
    mode: _score_pb2.Score.FetchingMode
    time_offset: int
    def __init__(self, contest_id: _Optional[str] = ..., mode: _Optional[_Union[_score_pb2.Score.FetchingMode, str]] = ..., time_offset: _Optional[int] = ...) -> None: ...

class ExportResultOutput(_message.Message):
    __slots__ = ["export_url"]
    EXPORT_URL_FIELD_NUMBER: _ClassVar[int]
    export_url: str
    def __init__(self, export_url: _Optional[str] = ...) -> None: ...

class ExportScoreInput(_message.Message):
    __slots__ = ["contest_id", "participant_id"]
    CONTEST_ID_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANT_ID_FIELD_NUMBER: _ClassVar[int]
    contest_id: str
    participant_id: str
    def __init__(self, contest_id: _Optional[str] = ..., participant_id: _Optional[str] = ...) -> None: ...

class ExportScoreOutput(_message.Message):
    __slots__ = ["scores"]
    SCORES_FIELD_NUMBER: _ClassVar[int]
    scores: _containers.RepeatedCompositeFieldContainer[_score_pb2.Score]
    def __init__(self, scores: _Optional[_Iterable[_Union[_score_pb2.Score, _Mapping]]] = ...) -> None: ...

class ImportScoreInput(_message.Message):
    __slots__ = ["contest_id", "participant_id", "scores"]
    CONTEST_ID_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANT_ID_FIELD_NUMBER: _ClassVar[int]
    SCORES_FIELD_NUMBER: _ClassVar[int]
    contest_id: str
    participant_id: str
    scores: _containers.RepeatedCompositeFieldContainer[_score_pb2.Score]
    def __init__(self, contest_id: _Optional[str] = ..., participant_id: _Optional[str] = ..., scores: _Optional[_Iterable[_Union[_score_pb2.Score, _Mapping]]] = ...) -> None: ...

class ImportScoreOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class IntrospectScoreInput(_message.Message):
    __slots__ = ["contest_id"]
    CONTEST_ID_FIELD_NUMBER: _ClassVar[int]
    contest_id: str
    def __init__(self, contest_id: _Optional[str] = ...) -> None: ...

class IntrospectScoreOutput(_message.Message):
    __slots__ = ["score"]
    SCORE_FIELD_NUMBER: _ClassVar[int]
    score: _score_pb2.Score
    def __init__(self, score: _Optional[_Union[_score_pb2.Score, _Mapping]] = ...) -> None: ...

class ListResultInput(_message.Message):
    __slots__ = ["contest_id", "mode", "offset", "size", "time_offset"]
    CONTEST_ID_FIELD_NUMBER: _ClassVar[int]
    MODE_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    TIME_OFFSET_FIELD_NUMBER: _ClassVar[int]
    contest_id: str
    mode: _score_pb2.Score.FetchingMode
    offset: int
    size: int
    time_offset: int
    def __init__(self, contest_id: _Optional[str] = ..., mode: _Optional[_Union[_score_pb2.Score.FetchingMode, str]] = ..., time_offset: _Optional[int] = ..., offset: _Optional[int] = ..., size: _Optional[int] = ...) -> None: ...

class ListResultOutput(_message.Message):
    __slots__ = ["items", "total"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_result_pb2.Result]
    total: int
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_result_pb2.Result, _Mapping]]] = ...) -> None: ...

class RebuildScoreInput(_message.Message):
    __slots__ = ["contest_id"]
    CONTEST_ID_FIELD_NUMBER: _ClassVar[int]
    contest_id: str
    def __init__(self, contest_id: _Optional[str] = ...) -> None: ...

class RebuildScoreOutput(_message.Message):
    __slots__ = ["activity_id"]
    ACTIVITY_ID_FIELD_NUMBER: _ClassVar[int]
    activity_id: str
    def __init__(self, activity_id: _Optional[str] = ...) -> None: ...

class WatchScoreInput(_message.Message):
    __slots__ = ["contest_id", "mode", "participant_id"]
    CONTEST_ID_FIELD_NUMBER: _ClassVar[int]
    MODE_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANT_ID_FIELD_NUMBER: _ClassVar[int]
    contest_id: str
    mode: _score_pb2.Score.FetchingMode
    participant_id: str
    def __init__(self, contest_id: _Optional[str] = ..., participant_id: _Optional[str] = ..., mode: _Optional[_Union[_score_pb2.Score.FetchingMode, str]] = ...) -> None: ...

class WatchScoreOutput(_message.Message):
    __slots__ = ["score"]
    SCORE_FIELD_NUMBER: _ClassVar[int]
    score: _score_pb2.Score
    def __init__(self, score: _Optional[_Union[_score_pb2.Score, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler. DO NOT EDIT!
# See https://github.com/eolymp/contracts/tree/main/cmd/protoc-gen-python-esdk for more details.
"""Generated protocol buffer code."""

import urllib.parse
from google.protobuf import symbol_database as _symbol_database

_sym_db = _symbol_database.Default()


class ProblemServiceClient:
    def __init__(self, transport, url="https://api.eolymp.com"):
        self.transport = transport
        self.url = url

    def ListStatements(self, request, **kwargs):
        path = "/statements"

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.course.ListStatementsOutput"),
            **kwargs,
        )

    def ListExamples(self, request, **kwargs):
        path = "/examples"

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.course.ListExamplesOutput"),
            **kwargs,
        )

    def CreateSubmission(self, request, **kwargs):
        path = "/submissions"

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.course.CreateSubmissionOutput"),
            **kwargs,
        )

    def ListSubmissions(self, request, **kwargs):
        path = "/submissions"

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.course.ListSubmissionsOutput"),
            **kwargs,
        )

    def DescribeSubmission(self, request, **kwargs):
        path = "/submissions/"+urllib.parse.quote(request.submission_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.submission_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.course.DescribeSubmissionOutput"),
            **kwargs,
        )

    def LookupCodeTemplate(self, request, **kwargs):
        path = "/template"

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.course.LookupCodeTemplateOutput"),
            **kwargs,
        )

    def CreateRun(self, request, **kwargs):
        path = "/runs"

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.course.CreateRunOutput"),
            **kwargs,
        )

    def DescribeRun(self, request, **kwargs):
        path = "/runs/"+urllib.parse.quote(request.run_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.run_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.course.DescribeRunOutput"),
            **kwargs,
        )

    def WatchRun(self, request, **kwargs):
        path = "/runs/"+urllib.parse.quote(request.run_id)+"/watch"

        # Cleanup URL parameters to avoid any ambiguity
        request.run_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.course.WatchRunOutput"),
            **kwargs,
        )




# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/cognito/cognito.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.cognito import access_key_pb2 as eolymp_dot_cognito_dot_access__key__pb2
from eolymp.cognito import quota_pb2 as eolymp_dot_cognito_dot_quota__pb2
from eolymp.cognito import user_pb2 as eolymp_dot_cognito_dot_user__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x65olymp/cognito/cognito.proto\x12\x0e\x65olymp.cognito\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1f\x65olymp/cognito/access_key.proto\x1a\x1a\x65olymp/cognito/quota.proto\x1a\x19\x65olymp/cognito/user.proto\x1a!eolymp/wellknown/expression.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xcc\x02\n\x10\x43reateTokenInput\x12>\n\ngrant_type\x18\x01 \x01(\x0e\x32*.eolymp.cognito.CreateTokenInput.GrantType\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\t\x12\x11\n\tclient_id\x18\x04 \x01(\t\x12\x15\n\rclient_secret\x18\x05 \x01(\t\x12\x0c\n\x04\x63ode\x18\x06 \x01(\t\x12\x15\n\rcode_verifier\x18\x07 \x01(\t\x12\r\n\x05scope\x18\x08 \x01(\t\x12\x15\n\rrefresh_token\x18\t \x01(\t\"_\n\tGrantType\x12\x08\n\x04NONE\x10\x00\x12\x0c\n\x08PASSWORD\x10\x01\x12\x16\n\x12\x41UTHORIZATION_CODE\x10\x02\x12\x11\n\rREFRESH_TOKEN\x10\x03\x12\x0f\n\x0bGOOGLE_CODE\x10\x04\"\xaa\x01\n\x11\x43reateTokenOutput\x12\r\n\x05token\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12.\n\nexpires_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06scopes\x18\x04 \x03(\t\x12\x15\n\rrefresh_token\x18\n \x01(\t\x12\x0f\n\x07user_id\x18\x64 \x01(\t\x12\x10\n\x08username\x18\x65 \x01(\t\"%\n\x14IntrospectTokenInput\x12\r\n\x05token\x18\x01 \x01(\t\"\xfd\x01\n\x15IntrospectTokenOutput\x12\x0e\n\x06\x61\x63tive\x18\x01 \x01(\x08\x12\r\n\x05scope\x18\x02 \x01(\t\x12*\n\x06\x65xpire\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07subject\x18\x04 \x01(\t\x12\x10\n\x08\x61udience\x18\x05 \x01(\t\x12\x0e\n\x06issuer\x18\x06 \x01(\t\x12\x0c\n\x04name\x18\x64 \x01(\t\x12\x10\n\x08nickname\x18\x65 \x01(\t\x12\x0f\n\x07picture\x18\x66 \x01(\t\x12\r\n\x05\x65mail\x18g \x01(\t\x12\x16\n\x0e\x65mail_verified\x18h \x01(\x08\x12\x0e\n\x06locale\x18i \x01(\t\"\xaf\x01\n\x18\x43reateAuthorizationInput\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x16\n\x0e\x63ode_challenge\x18\x02 \x01(\t\x12\x1d\n\x15\x63ode_challenge_method\x18\x03 \x01(\t\x12\x14\n\x0credirect_uri\x18\x04 \x01(\t\x12\x15\n\rresponse_type\x18\x05 \x01(\t\x12\r\n\x05scope\x18\x06 \x01(\t\x12\r\n\x05state\x18\x07 \x01(\t\"M\n\x19\x43reateAuthorizationOutput\x12\x1a\n\x12\x61uthorization_code\x18\x01 \x01(\t\x12\x14\n\x0credirect_uri\x18\x02 \x01(\t\"\x16\n\x14IntrospectQuotaInput\"\xe9\x01\n\x15IntrospectQuotaOutput\x12\x30\n\x11\x63ontests_per_user\x18\n \x01(\x0b\x32\x15.eolymp.cognito.Quota\x12\x33\n\x14problems_per_contest\x18\x0b \x01(\x0b\x32\x15.eolymp.cognito.Quota\x12\x37\n\x18participants_per_contest\x18\x0c \x01(\x0b\x32\x15.eolymp.cognito.Quota\x12\x30\n\x11problems_per_user\x18\x14 \x01(\x0b\x32\x15.eolymp.cognito.Quota\"\x15\n\x13IntrospectUserInput\":\n\x14IntrospectUserOutput\x12\"\n\x04user\x18\x01 \x01(\x0b\x32\x14.eolymp.cognito.User\"$\n\x11\x44\x65scribeUserInput\x12\x0f\n\x07user_id\x18\x01 \x01(\t\"8\n\x12\x44\x65scribeUserOutput\x12\"\n\x04user\x18\x01 \x01(\x0b\x32\x14.eolymp.cognito.User\"\xd2\x01\n\x0eListUsersInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x36\n\x07\x66ilters\x18( \x01(\x0b\x32%.eolymp.cognito.ListUsersInput.Filter\x1aj\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x34\n\x08username\x18\x02 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\"E\n\x0fListUsersOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12#\n\x05items\x18\x02 \x03(\x0b\x32\x14.eolymp.cognito.User\"\x9b\x01\n\x0f\x43reateUserInput\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x11\n\tfull_name\x18\x02 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\x12\x10\n\x08password\x18\x04 \x01(\t\x12\x0f\n\x07\x63ountry\x18\x05 \x01(\t\x12\x10\n\x08\x62irthday\x18\x06 \x01(\t\x12\x0f\n\x07\x63\x61ptcha\x18\n \x01(\t\x12\x0e\n\x06locale\x18\x14 \x01(\t\"D\n\x10\x43reateUserOutput\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x1f\n\x17\x65mail_confirmation_hint\x18\x02 \x01(\t\"\xac\x01\n\x0fNotifyUserInput\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x10\n\x08template\x18\x02 \x01(\t\x12\x43\n\nparameters\x18\x03 \x03(\x0b\x32/.eolymp.cognito.NotifyUserInput.ParametersEntry\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"+\n\x10NotifyUserOutput\x12\x17\n\x0fnotification_id\x18\x01 \x01(\t\"3\n\x10VerifyEmailInput\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x0e\n\x06secret\x18\x02 \x01(\t\"\x13\n\x11VerifyEmailOutput\"!\n\x10UpdateEmailInput\x12\r\n\x05\x65mail\x18\x01 \x01(\t\"4\n\x11UpdateEmailOutput\x12\x1f\n\x17\x65mail_confirmation_hint\x18\x02 \x01(\t\"\xdc\x02\n\x12UpdateProfileInput\x12\x37\n\x05patch\x18\x01 \x03(\x0e\x32(.eolymp.cognito.UpdateProfileInput.Patch\x12\x10\n\x08username\x18\x02 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\n \x01(\t\x12\x0f\n\x07\x63ompany\x18\x0c \x01(\t\x12\x12\n\noccupation\x18\r \x01(\t\x12\x0f\n\x07\x63ountry\x18\x15 \x01(\t\x12\x0c\n\x04\x63ity\x18\x16 \x01(\t\x12\x10\n\x08\x62irthday\x18! \x01(\t\x12\x0e\n\x06locale\x18\" \x01(\t\"x\n\x05Patch\x12\x0c\n\x08USERNAME\x10\x00\x12\t\n\x05\x45MAIL\x10\x01\x12\x08\n\x04NAME\x10\x02\x12\x0b\n\x07\x43OMPANY\x10\x03\x12\x0e\n\nOCCUPATION\x10\x04\x12\x0b\n\x07\x43OUNTRY\x10\x05\x12\x08\n\x04\x43ITY\x10\x06\x12\x0c\n\x08\x42IRTHDAY\x10\x07\x12\n\n\x06LOCALE\x10\x08\"6\n\x13UpdateProfileOutput\x12\x1f\n\x17\x65mail_confirmation_hint\x18\x01 \x01(\t\"f\n\x12UpdatePictureInput\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\x10\n\x08offset_x\x18\n \x01(\r\x12\x10\n\x08offset_y\x18\x0b \x01(\r\x12\x0c\n\x04size\x18\x0c \x01(\r\"\x15\n\x13UpdatePictureOutput\"E\n\x13UpdatePasswordInput\x12\x18\n\x10\x63urrent_password\x18\x01 \x01(\t\x12\x14\n\x0cnew_password\x18\x02 \x01(\t\"\x16\n\x14UpdatePasswordOutput\"\x1e\n\x1cResendEmailVerificationInput\"@\n\x1dResendEmailVerificationOutput\x12\x1f\n\x17\x65mail_confirmation_hint\x18\x01 \x01(\t\"D\n\x12StartRecoveryInput\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x0f\n\x07\x63\x61ptcha\x18\x02 \x01(\t\x12\x0e\n\x06locale\x18\x14 \x01(\t\"2\n\x13StartRecoveryOutput\x12\x1b\n\x13\x65mail_recovery_hint\x18\x01 \x01(\t\"I\n\x14\x43ompleteRecoverInput\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x0e\n\x06secret\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\t\"\x17\n\x15\x43ompleteRecoverOutput\"\x16\n\x14IntrospectRolesInput\"&\n\x15IntrospectRolesOutput\x12\r\n\x05roles\x18\x01 \x03(\t\"!\n\x0eListRolesInput\x12\x0f\n\x07user_id\x18\x01 \x01(\t\" \n\x0fListRolesOutput\x12\r\n\x05roles\x18\x01 \x03(\t\"2\n\x10UpdateRolesInput\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\r\n\x05roles\x18\x02 \x03(\t\"\x13\n\x11UpdateRolesOutput\"\x13\n\x11SelfDestructInput\"C\n\x12SelfDestructOutput\x12-\n\tdelete_on\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"!\n\x10RevokeTokenInput\x12\r\n\x05token\x18\x01 \x01(\t\"\x13\n\x11RevokeTokenOutput\"1\n\x0bSigninInput\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\"2\n\x0cSigninOutput\x12\"\n\x04user\x18\x01 \x01(\x0b\x32\x14.eolymp.cognito.User\"\"\n\x0cSignoutInput\x12\x12\n\neverywhere\x18\x01 \x01(\x08\"\x0f\n\rSignoutOutput\"G\n\x14\x43reateAccessKeyInput\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05scope\x18\x02 \x01(\t\x12\x12\n\nexpires_in\x18\x03 \x01(\r\"7\n\x15\x43reateAccessKeyOutput\x12\x0e\n\x06key_id\x18\x01 \x01(\t\x12\x0e\n\x06secret\x18\x02 \x01(\t\"&\n\x14\x44\x65leteAccessKeyInput\x12\x0e\n\x06key_id\x18\x01 \x01(\t\"\x17\n\x15\x44\x65leteAccessKeyOutput\"3\n\x13ListAccessKeysInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\"O\n\x14ListAccessKeysOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12(\n\x05items\x18\x02 \x03(\x0b\x32\x19.eolymp.cognito.AccessKey2\xbf\x19\n\x07\x43ognito\x12\x64\n\x0b\x43reateToken\x12 .eolymp.cognito.CreateTokenInput\x1a!.eolymp.cognito.CreateTokenOutput\"\x10\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xf0\x41\xf8\xe2\n\xac\x02\x12o\n\x0fIntrospectToken\x12$.eolymp.cognito.IntrospectTokenInput\x1a%.eolymp.cognito.IntrospectTokenOutput\"\x0f\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x12\x63\n\x0bRevokeToken\x12 .eolymp.cognito.RevokeTokenInput\x1a!.eolymp.cognito.RevokeTokenOutput\"\x0f\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x12l\n\x07Signout\x12\x1c.eolymp.cognito.SignoutInput\x1a\x1d.eolymp.cognito.SignoutOutput\"$\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x0f\"\r/self/signout\x12\xa3\x01\n\x0f\x43reateAccessKey\x12$.eolymp.cognito.CreateAccessKeyInput\x1a%.eolymp.cognito.CreateAccessKeyOutput\"C\x82\xe3\n\x1c\x8a\xe3\n\x18\x63ognito:access-key:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x0e\"\x0c/access-keys\x12\xac\x01\n\x0f\x44\x65leteAccessKey\x12$.eolymp.cognito.DeleteAccessKeyInput\x1a%.eolymp.cognito.DeleteAccessKeyOutput\"L\x82\xe3\n\x1c\x8a\xe3\n\x18\x63ognito:access-key:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x17*\x15/access-keys/{key_id}\x12\x9f\x01\n\x0eListAccessKeys\x12#.eolymp.cognito.ListAccessKeysInput\x1a$.eolymp.cognito.ListAccessKeysOutput\"B\x82\xe3\n\x1b\x8a\xe3\n\x17\x63ognito:access-key:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x0e\x12\x0c/access-keys\x12n\n\nCreateUser\x12\x1f.eolymp.cognito.CreateUserInput\x1a .eolymp.cognito.CreateUserOutput\"\x1d\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x08\"\x06/users\x12\x82\x01\n\x0bVerifyEmail\x12 .eolymp.cognito.VerifyEmailInput\x1a!.eolymp.cognito.VerifyEmailOutput\".\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x01\x82\xd3\xe4\x93\x02\x19\"\x17/users/{user_id}/verify\x12\xae\x01\n\x17ResendEmailVerification\x12,.eolymp.cognito.ResendEmailVerificationInput\x1a-.eolymp.cognito.ResendEmailVerificationOutput\"6\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02!\"\x1f/self/email/resend-verification\x12v\n\x0bUpdateEmail\x12 .eolymp.cognito.UpdateEmailInput\x1a!.eolymp.cognito.UpdateEmailOutput\"\"\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x01\x82\xd3\xe4\x93\x02\r\"\x0b/self/email\x12v\n\rUpdateProfile\x12\".eolymp.cognito.UpdateProfileInput\x1a#.eolymp.cognito.UpdateProfileOutput\"\x1c\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x07\"\x05/self\x12~\n\rUpdatePicture\x12\".eolymp.cognito.UpdatePictureInput\x1a#.eolymp.cognito.UpdatePictureOutput\"$\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x0f\"\r/self/picture\x12\x98\x01\n\x0eUpdatePassword\x12#.eolymp.cognito.UpdatePasswordInput\x1a$.eolymp.cognito.UpdatePasswordOutput\";\x82\xe3\n\x12\x8a\xe3\n\x0epassword_grant\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x10\"\x0e/self/password\x12y\n\x0eIntrospectUser\x12#.eolymp.cognito.IntrospectUserInput\x1a$.eolymp.cognito.IntrospectUserOutput\"\x1c\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x07\x12\x05/self\x12\x98\x01\n\x0c\x44\x65scribeUser\x12!.eolymp.cognito.DescribeUserInput\x1a\".eolymp.cognito.DescribeUserOutput\"A\x82\xe3\n\x15\x8a\xe3\n\x11\x63ognito:user:read\xea\xe2\n\x0c\xf5\xe2\n\x00\x00HC\xf8\xe2\n\xf4\x03\x82\xd3\xe4\x93\x02\x12\x12\x10/users/{user_id}\x12\x84\x01\n\tListUsers\x12\x1e.eolymp.cognito.ListUsersInput\x1a\x1f.eolymp.cognito.ListUsersOutput\"6\x82\xe3\n\x15\x8a\xe3\n\x11\x63ognito:user:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00pA\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x08\x12\x06/users\x12\x82\x01\n\x0fIntrospectQuota\x12$.eolymp.cognito.IntrospectQuotaInput\x1a%.eolymp.cognito.IntrospectQuotaOutput\"\"\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02\r\x12\x0b/self/quota\x12\x82\x01\n\x0fIntrospectRoles\x12$.eolymp.cognito.IntrospectRolesInput\x1a%.eolymp.cognito.IntrospectRolesOutput\"\"\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02\r\x12\x0b/self/roles\x12\x94\x01\n\tListRoles\x12\x1e.eolymp.cognito.ListRolesInput\x1a\x1f.eolymp.cognito.ListRolesOutput\"F\x82\xe3\n\x15\x8a\xe3\n\x11\x63ognito:role:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x18\x12\x16/users/{user_id}/roles\x12\x9a\x01\n\x0bUpdateRoles\x12 .eolymp.cognito.UpdateRolesInput\x1a!.eolymp.cognito.UpdateRolesOutput\"F\x82\xe3\n\x15\x8a\xe3\n\x11\x63ognito:role:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x18\x1a\x16/users/{user_id}/roles\x12\x7f\n\rStartRecovery\x12\".eolymp.cognito.StartRecoveryInput\x1a#.eolymp.cognito.StartRecoveryOutput\"%\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x10\"\x0e/self/recovery\x12\x90\x01\n\x10\x43ompleteRecovery\x12$.eolymp.cognito.CompleteRecoverInput\x1a%.eolymp.cognito.CompleteRecoverOutput\"/\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x1a\"\x18/users/{user_id}/recover\x12s\n\x0cSelfDestruct\x12!.eolymp.cognito.SelfDestructInput\x1a\".eolymp.cognito.SelfDestructOutput\"\x1c\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x07*\x05/selfB1Z/github.com/eolymp/go-sdk/eolymp/cognito;cognitob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.cognito.cognito_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z/github.com/eolymp/go-sdk/eolymp/cognito;cognito'
  _NOTIFYUSERINPUT_PARAMETERSENTRY._options = None
  _NOTIFYUSERINPUT_PARAMETERSENTRY._serialized_options = b'8\001'
  _COGNITO.methods_by_name['CreateToken']._options = None
  _COGNITO.methods_by_name['CreateToken']._serialized_options = b'\352\342\n\014\365\342\n\000\000\360A\370\342\n\254\002'
  _COGNITO.methods_by_name['IntrospectToken']._options = None
  _COGNITO.methods_by_name['IntrospectToken']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2'
  _COGNITO.methods_by_name['RevokeToken']._options = None
  _COGNITO.methods_by_name['RevokeToken']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\n'
  _COGNITO.methods_by_name['Signout']._options = None
  _COGNITO.methods_by_name['Signout']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\323\344\223\002\017\"\r/self/signout'
  _COGNITO.methods_by_name['CreateAccessKey']._options = None
  _COGNITO.methods_by_name['CreateAccessKey']._serialized_options = b'\202\343\n\034\212\343\n\030cognito:access-key:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\323\344\223\002\016\"\014/access-keys'
  _COGNITO.methods_by_name['DeleteAccessKey']._options = None
  _COGNITO.methods_by_name['DeleteAccessKey']._serialized_options = b'\202\343\n\034\212\343\n\030cognito:access-key:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\027*\025/access-keys/{key_id}'
  _COGNITO.methods_by_name['ListAccessKeys']._options = None
  _COGNITO.methods_by_name['ListAccessKeys']._serialized_options = b'\202\343\n\033\212\343\n\027cognito:access-key:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\016\022\014/access-keys'
  _COGNITO.methods_by_name['CreateUser']._options = None
  _COGNITO.methods_by_name['CreateUser']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002\010\"\006/users'
  _COGNITO.methods_by_name['VerifyEmail']._options = None
  _COGNITO.methods_by_name['VerifyEmail']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\001\202\323\344\223\002\031\"\027/users/{user_id}/verify'
  _COGNITO.methods_by_name['ResendEmailVerification']._options = None
  _COGNITO.methods_by_name['ResendEmailVerification']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002!\"\037/self/email/resend-verification'
  _COGNITO.methods_by_name['UpdateEmail']._options = None
  _COGNITO.methods_by_name['UpdateEmail']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\001\202\323\344\223\002\r\"\013/self/email'
  _COGNITO.methods_by_name['UpdateProfile']._options = None
  _COGNITO.methods_by_name['UpdateProfile']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\007\"\005/self'
  _COGNITO.methods_by_name['UpdatePicture']._options = None
  _COGNITO.methods_by_name['UpdatePicture']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\017\"\r/self/picture'
  _COGNITO.methods_by_name['UpdatePassword']._options = None
  _COGNITO.methods_by_name['UpdatePassword']._serialized_options = b'\202\343\n\022\212\343\n\016password_grant\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\020\"\016/self/password'
  _COGNITO.methods_by_name['IntrospectUser']._options = None
  _COGNITO.methods_by_name['IntrospectUser']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002\007\022\005/self'
  _COGNITO.methods_by_name['DescribeUser']._options = None
  _COGNITO.methods_by_name['DescribeUser']._serialized_options = b'\202\343\n\025\212\343\n\021cognito:user:read\352\342\n\014\365\342\n\000\000HC\370\342\n\364\003\202\323\344\223\002\022\022\020/users/{user_id}'
  _COGNITO.methods_by_name['ListUsers']._options = None
  _COGNITO.methods_by_name['ListUsers']._serialized_options = b'\202\343\n\025\212\343\n\021cognito:user:read\352\342\n\013\365\342\n\000\000pA\370\342\nd\202\323\344\223\002\010\022\006/users'
  _COGNITO.methods_by_name['IntrospectQuota']._options = None
  _COGNITO.methods_by_name['IntrospectQuota']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002\r\022\013/self/quota'
  _COGNITO.methods_by_name['IntrospectRoles']._options = None
  _COGNITO.methods_by_name['IntrospectRoles']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002\r\022\013/self/roles'
  _COGNITO.methods_by_name['ListRoles']._options = None
  _COGNITO.methods_by_name['ListRoles']._serialized_options = b'\202\343\n\025\212\343\n\021cognito:role:read\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\323\344\223\002\030\022\026/users/{user_id}/roles'
  _COGNITO.methods_by_name['UpdateRoles']._options = None
  _COGNITO.methods_by_name['UpdateRoles']._serialized_options = b'\202\343\n\025\212\343\n\021cognito:role:read\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\323\344\223\002\030\032\026/users/{user_id}/roles'
  _COGNITO.methods_by_name['StartRecovery']._options = None
  _COGNITO.methods_by_name['StartRecovery']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\005\202\323\344\223\002\020\"\016/self/recovery'
  _COGNITO.methods_by_name['CompleteRecovery']._options = None
  _COGNITO.methods_by_name['CompleteRecovery']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002\032\"\030/users/{user_id}/recover'
  _COGNITO.methods_by_name['SelfDestruct']._options = None
  _COGNITO.methods_by_name['SelfDestruct']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\323\344\223\002\007*\005/self'
  _CREATETOKENINPUT._serialized_start=304
  _CREATETOKENINPUT._serialized_end=636
  _CREATETOKENINPUT_GRANTTYPE._serialized_start=541
  _CREATETOKENINPUT_GRANTTYPE._serialized_end=636
  _CREATETOKENOUTPUT._serialized_start=639
  _CREATETOKENOUTPUT._serialized_end=809
  _INTROSPECTTOKENINPUT._serialized_start=811
  _INTROSPECTTOKENINPUT._serialized_end=848
  _INTROSPECTTOKENOUTPUT._serialized_start=851
  _INTROSPECTTOKENOUTPUT._serialized_end=1104
  _CREATEAUTHORIZATIONINPUT._serialized_start=1107
  _CREATEAUTHORIZATIONINPUT._serialized_end=1282
  _CREATEAUTHORIZATIONOUTPUT._serialized_start=1284
  _CREATEAUTHORIZATIONOUTPUT._serialized_end=1361
  _INTROSPECTQUOTAINPUT._serialized_start=1363
  _INTROSPECTQUOTAINPUT._serialized_end=1385
  _INTROSPECTQUOTAOUTPUT._serialized_start=1388
  _INTROSPECTQUOTAOUTPUT._serialized_end=1621
  _INTROSPECTUSERINPUT._serialized_start=1623
  _INTROSPECTUSERINPUT._serialized_end=1644
  _INTROSPECTUSEROUTPUT._serialized_start=1646
  _INTROSPECTUSEROUTPUT._serialized_end=1704
  _DESCRIBEUSERINPUT._serialized_start=1706
  _DESCRIBEUSERINPUT._serialized_end=1742
  _DESCRIBEUSEROUTPUT._serialized_start=1744
  _DESCRIBEUSEROUTPUT._serialized_end=1800
  _LISTUSERSINPUT._serialized_start=1803
  _LISTUSERSINPUT._serialized_end=2013
  _LISTUSERSINPUT_FILTER._serialized_start=1907
  _LISTUSERSINPUT_FILTER._serialized_end=2013
  _LISTUSERSOUTPUT._serialized_start=2015
  _LISTUSERSOUTPUT._serialized_end=2084
  _CREATEUSERINPUT._serialized_start=2087
  _CREATEUSERINPUT._serialized_end=2242
  _CREATEUSEROUTPUT._serialized_start=2244
  _CREATEUSEROUTPUT._serialized_end=2312
  _NOTIFYUSERINPUT._serialized_start=2315
  _NOTIFYUSERINPUT._serialized_end=2487
  _NOTIFYUSERINPUT_PARAMETERSENTRY._serialized_start=2438
  _NOTIFYUSERINPUT_PARAMETERSENTRY._serialized_end=2487
  _NOTIFYUSEROUTPUT._serialized_start=2489
  _NOTIFYUSEROUTPUT._serialized_end=2532
  _VERIFYEMAILINPUT._serialized_start=2534
  _VERIFYEMAILINPUT._serialized_end=2585
  _VERIFYEMAILOUTPUT._serialized_start=2587
  _VERIFYEMAILOUTPUT._serialized_end=2606
  _UPDATEEMAILINPUT._serialized_start=2608
  _UPDATEEMAILINPUT._serialized_end=2641
  _UPDATEEMAILOUTPUT._serialized_start=2643
  _UPDATEEMAILOUTPUT._serialized_end=2695
  _UPDATEPROFILEINPUT._serialized_start=2698
  _UPDATEPROFILEINPUT._serialized_end=3046
  _UPDATEPROFILEINPUT_PATCH._serialized_start=2926
  _UPDATEPROFILEINPUT_PATCH._serialized_end=3046
  _UPDATEPROFILEOUTPUT._serialized_start=3048
  _UPDATEPROFILEOUTPUT._serialized_end=3102
  _UPDATEPICTUREINPUT._serialized_start=3104
  _UPDATEPICTUREINPUT._serialized_end=3206
  _UPDATEPICTUREOUTPUT._serialized_start=3208
  _UPDATEPICTUREOUTPUT._serialized_end=3229
  _UPDATEPASSWORDINPUT._serialized_start=3231
  _UPDATEPASSWORDINPUT._serialized_end=3300
  _UPDATEPASSWORDOUTPUT._serialized_start=3302
  _UPDATEPASSWORDOUTPUT._serialized_end=3324
  _RESENDEMAILVERIFICATIONINPUT._serialized_start=3326
  _RESENDEMAILVERIFICATIONINPUT._serialized_end=3356
  _RESENDEMAILVERIFICATIONOUTPUT._serialized_start=3358
  _RESENDEMAILVERIFICATIONOUTPUT._serialized_end=3422
  _STARTRECOVERYINPUT._serialized_start=3424
  _STARTRECOVERYINPUT._serialized_end=3492
  _STARTRECOVERYOUTPUT._serialized_start=3494
  _STARTRECOVERYOUTPUT._serialized_end=3544
  _COMPLETERECOVERINPUT._serialized_start=3546
  _COMPLETERECOVERINPUT._serialized_end=3619
  _COMPLETERECOVEROUTPUT._serialized_start=3621
  _COMPLETERECOVEROUTPUT._serialized_end=3644
  _INTROSPECTROLESINPUT._serialized_start=3646
  _INTROSPECTROLESINPUT._serialized_end=3668
  _INTROSPECTROLESOUTPUT._serialized_start=3670
  _INTROSPECTROLESOUTPUT._serialized_end=3708
  _LISTROLESINPUT._serialized_start=3710
  _LISTROLESINPUT._serialized_end=3743
  _LISTROLESOUTPUT._serialized_start=3745
  _LISTROLESOUTPUT._serialized_end=3777
  _UPDATEROLESINPUT._serialized_start=3779
  _UPDATEROLESINPUT._serialized_end=3829
  _UPDATEROLESOUTPUT._serialized_start=3831
  _UPDATEROLESOUTPUT._serialized_end=3850
  _SELFDESTRUCTINPUT._serialized_start=3852
  _SELFDESTRUCTINPUT._serialized_end=3871
  _SELFDESTRUCTOUTPUT._serialized_start=3873
  _SELFDESTRUCTOUTPUT._serialized_end=3940
  _REVOKETOKENINPUT._serialized_start=3942
  _REVOKETOKENINPUT._serialized_end=3975
  _REVOKETOKENOUTPUT._serialized_start=3977
  _REVOKETOKENOUTPUT._serialized_end=3996
  _SIGNININPUT._serialized_start=3998
  _SIGNININPUT._serialized_end=4047
  _SIGNINOUTPUT._serialized_start=4049
  _SIGNINOUTPUT._serialized_end=4099
  _SIGNOUTINPUT._serialized_start=4101
  _SIGNOUTINPUT._serialized_end=4135
  _SIGNOUTOUTPUT._serialized_start=4137
  _SIGNOUTOUTPUT._serialized_end=4152
  _CREATEACCESSKEYINPUT._serialized_start=4154
  _CREATEACCESSKEYINPUT._serialized_end=4225
  _CREATEACCESSKEYOUTPUT._serialized_start=4227
  _CREATEACCESSKEYOUTPUT._serialized_end=4282
  _DELETEACCESSKEYINPUT._serialized_start=4284
  _DELETEACCESSKEYINPUT._serialized_end=4322
  _DELETEACCESSKEYOUTPUT._serialized_start=4324
  _DELETEACCESSKEYOUTPUT._serialized_end=4347
  _LISTACCESSKEYSINPUT._serialized_start=4349
  _LISTACCESSKEYSINPUT._serialized_end=4400
  _LISTACCESSKEYSOUTPUT._serialized_start=4402
  _LISTACCESSKEYSOUTPUT._serialized_end=4481
  _COGNITO._serialized_start=4484
  _COGNITO._serialized_end=7747
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/atlas/solution_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.atlas import solution_pb2 as eolymp_dot_atlas_dot_solution__pb2
from eolymp.wellknown import direction_pb2 as eolymp_dot_wellknown_dot_direction__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#eolymp/atlas/solution_service.proto\x12\x0c\x65olymp.atlas\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1b\x65olymp/atlas/solution.proto\x1a eolymp/wellknown/direction.proto\x1a!eolymp/wellknown/expression.proto\"\xf1\x03\n\x12ListSolutionsInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x64 \x01(\r\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x38\n\x07\x66ilters\x18( \x01(\x0b\x32\'.eolymp.atlas.ListSolutionsInput.Filter\x12\x37\n\x04sort\x18\x32 \x01(\x0e\x32).eolymp.atlas.ListSolutionsInput.Sortable\x12*\n\x05order\x18\x33 \x01(\x0e\x32\x1b.eolymp.wellknown.Direction\x1a\xd8\x01\n\x06\x46ilter\x12\r\n\x05query\x18\x01 \x01(\t\x12*\n\x02id\x18\n \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12.\n\x04type\x18\x0b \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x30\n\x04name\x18\x0c \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12\x31\n\x07runtime\x18\r \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"\x1e\n\x08Sortable\x12\x08\n\x04NAME\x10\x00\x12\x08\n\x04TYPE\x10\x01\"K\n\x13ListSolutionsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12%\n\x05items\x18\x02 \x03(\x0b\x32\x16.eolymp.atlas.Solution\"Q\n\x15\x44\x65scribeSolutionInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x13\n\x0bsolution_id\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x64 \x01(\r\"B\n\x16\x44\x65scribeSolutionOutput\x12(\n\x08solution\x18\x01 \x01(\x0b\x32\x16.eolymp.atlas.Solution\"S\n\x13\x43reateSolutionInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12(\n\x08solution\x18\x02 \x01(\x0b\x32\x16.eolymp.atlas.Solution\"+\n\x14\x43reateSolutionOutput\x12\x13\n\x0bsolution_id\x18\x01 \x01(\t\"\xeb\x01\n\x13UpdateSolutionInput\x12\x36\n\x05patch\x18\x01 \x03(\x0e\x32\'.eolymp.atlas.UpdateSolutionInput.Patch\x12\x12\n\nproblem_id\x18\x02 \x01(\t\x12\x13\n\x0bsolution_id\x18\x03 \x01(\t\x12(\n\x08solution\x18\x04 \x01(\x0b\x32\x16.eolymp.atlas.Solution\"I\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\x08\n\x04NAME\x10\x01\x12\x08\n\x04TYPE\x10\x02\x12\x0b\n\x07RUNTIME\x10\x03\x12\n\n\x06SOURCE\x10\x04\x12\n\n\x06SECRET\x10\x05\"\x16\n\x14UpdateSolutionOutput\">\n\x13\x44\x65leteSolutionInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x13\n\x0bsolution_id\x18\x02 \x01(\t\"\x16\n\x14\x44\x65leteSolutionOutput2\xb4\x06\n\x0fSolutionService\x12\x95\x01\n\x0e\x43reateSolution\x12!.eolymp.atlas.CreateSolutionInput\x1a\".eolymp.atlas.CreateSolutionOutput\"<\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x0c\x1a\n/solutions\x12\xa3\x01\n\x0eUpdateSolution\x12!.eolymp.atlas.UpdateSolutionInput\x1a\".eolymp.atlas.UpdateSolutionOutput\"J\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1a\x1a\x18/solutions/{solution_id}\x12\xa3\x01\n\x0e\x44\x65leteSolution\x12!.eolymp.atlas.DeleteSolutionInput\x1a\".eolymp.atlas.DeleteSolutionOutput\"J\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1a*\x18/solutions/{solution_id}\x12\xa8\x01\n\x10\x44\x65scribeSolution\x12#.eolymp.atlas.DescribeSolutionInput\x1a$.eolymp.atlas.DescribeSolutionOutput\"I\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x1a\x12\x18/solutions/{solution_id}\x12\x91\x01\n\rListSolutions\x12 .eolymp.atlas.ListSolutionsInput\x1a!.eolymp.atlas.ListSolutionsOutput\";\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x0c\x12\n/solutionsB-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.solution_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _SOLUTIONSERVICE.methods_by_name['CreateSolution']._options = None
  _SOLUTIONSERVICE.methods_by_name['CreateSolution']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\014\032\n/solutions'
  _SOLUTIONSERVICE.methods_by_name['UpdateSolution']._options = None
  _SOLUTIONSERVICE.methods_by_name['UpdateSolution']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\032\032\030/solutions/{solution_id}'
  _SOLUTIONSERVICE.methods_by_name['DeleteSolution']._options = None
  _SOLUTIONSERVICE.methods_by_name['DeleteSolution']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\032*\030/solutions/{solution_id}'
  _SOLUTIONSERVICE.methods_by_name['DescribeSolution']._options = None
  _SOLUTIONSERVICE.methods_by_name['DescribeSolution']._serialized_options = b'\202\343\n\026\212\343\n\022atlas:problem:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\032\022\030/solutions/{solution_id}'
  _SOLUTIONSERVICE.methods_by_name['ListSolutions']._options = None
  _SOLUTIONSERVICE.methods_by_name['ListSolutions']._serialized_options = b'\202\343\n\026\212\343\n\022atlas:problem:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\014\022\n/solutions'
  _LISTSOLUTIONSINPUT._serialized_start=251
  _LISTSOLUTIONSINPUT._serialized_end=748
  _LISTSOLUTIONSINPUT_FILTER._serialized_start=500
  _LISTSOLUTIONSINPUT_FILTER._serialized_end=716
  _LISTSOLUTIONSINPUT_SORTABLE._serialized_start=718
  _LISTSOLUTIONSINPUT_SORTABLE._serialized_end=748
  _LISTSOLUTIONSOUTPUT._serialized_start=750
  _LISTSOLUTIONSOUTPUT._serialized_end=825
  _DESCRIBESOLUTIONINPUT._serialized_start=827
  _DESCRIBESOLUTIONINPUT._serialized_end=908
  _DESCRIBESOLUTIONOUTPUT._serialized_start=910
  _DESCRIBESOLUTIONOUTPUT._serialized_end=976
  _CREATESOLUTIONINPUT._serialized_start=978
  _CREATESOLUTIONINPUT._serialized_end=1061
  _CREATESOLUTIONOUTPUT._serialized_start=1063
  _CREATESOLUTIONOUTPUT._serialized_end=1106
  _UPDATESOLUTIONINPUT._serialized_start=1109
  _UPDATESOLUTIONINPUT._serialized_end=1344
  _UPDATESOLUTIONINPUT_PATCH._serialized_start=1271
  _UPDATESOLUTIONINPUT_PATCH._serialized_end=1344
  _UPDATESOLUTIONOUTPUT._serialized_start=1346
  _UPDATESOLUTIONOUTPUT._serialized_end=1368
  _DELETESOLUTIONINPUT._serialized_start=1370
  _DELETESOLUTIONINPUT._serialized_end=1432
  _DELETESOLUTIONOUTPUT._serialized_start=1434
  _DELETESOLUTIONOUTPUT._serialized_end=1456
  _SOLUTIONSERVICE._serialized_start=1459
  _SOLUTIONSERVICE._serialized_end=2279
# @@protoc_insertion_point(module_scope)



from eolymp.ecm import content_pb2 as _content_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Ticket(_message.Message):
    __slots__ = ["contest_id", "created_at", "cursor", "id", "is_read", "last_reply_at", "member_id", "message", "participant_id", "raw_message", "read_at", "reply_count", "status", "subject", "updated_at"]
    class Extra(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    AWAITING: Ticket.Status
    CLOSED: Ticket.Status
    CONTEST_ID_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    CURSOR_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    IS_READ_FIELD_NUMBER: _ClassVar[int]
    LAST_REPLY_AT_FIELD_NUMBER: _ClassVar[int]
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_RENDER: Ticket.Extra
    MESSAGE_VALUE: Ticket.Extra
    NO_EXTRA: Ticket.Extra
    PARTICIPANT_ID_FIELD_NUMBER: _ClassVar[int]
    RAW_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    READ_AT_FIELD_NUMBER: _ClassVar[int]
    REPLY_COUNT_FIELD_NUMBER: _ClassVar[int]
    RESOLVED: Ticket.Status
    STATUS_FIELD_NUMBER: _ClassVar[int]
    SUBJECT_FIELD_NUMBER: _ClassVar[int]
    UNKNOWN_STATUS: Ticket.Status
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    contest_id: str
    created_at: _timestamp_pb2.Timestamp
    cursor: str
    id: str
    is_read: bool
    last_reply_at: _timestamp_pb2.Timestamp
    member_id: str
    message: _content_pb2.Content
    participant_id: str
    raw_message: str
    read_at: _timestamp_pb2.Timestamp
    reply_count: int
    status: Ticket.Status
    subject: str
    updated_at: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., contest_id: _Optional[str] = ..., participant_id: _Optional[str] = ..., member_id: _Optional[str] = ..., status: _Optional[_Union[Ticket.Status, str]] = ..., subject: _Optional[str] = ..., message: _Optional[_Union[_content_pb2.Content, _Mapping]] = ..., raw_message: _Optional[str] = ..., is_read: bool = ..., reply_count: _Optional[int] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., updated_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., read_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., last_reply_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., cursor: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/content/render_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.ecm import content_pb2 as eolymp_dot_ecm_dot_content__pb2
from eolymp.ecm import node_pb2 as eolymp_dot_ecm_dot_node__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#eolymp/content/render_service.proto\x12\x0e\x65olymp.content\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x18\x65olymp/ecm/content.proto\x1a\x15\x65olymp/ecm/node.proto\":\n\x12RenderContentInput\x12$\n\x07\x63ontent\x18\x01 \x01(\x0b\x32\x13.eolymp.ecm.Content\"7\n\x13RenderContentOutput\x12 \n\x06render\x18\x01 \x01(\x0b\x32\x10.eolymp.ecm.Node2\x8b\x01\n\rRenderService\x12z\n\rRenderContent\x12\".eolymp.content.RenderContentInput\x1a#.eolymp.content.RenderContentOutput\" \xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xc8\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x0b\"\t/rendererB1Z/github.com/eolymp/go-sdk/eolymp/content;contentb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.content.render_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z/github.com/eolymp/go-sdk/eolymp/content;content'
  _RENDERSERVICE.methods_by_name['RenderContent']._options = None
  _RENDERSERVICE.methods_by_name['RenderContent']._serialized_options = b'\352\342\n\013\365\342\n\000\000\310A\370\342\nd\202\323\344\223\002\013\"\t/renderer'
  _RENDERCONTENTINPUT._serialized_start=171
  _RENDERCONTENTINPUT._serialized_end=229
  _RENDERCONTENTOUTPUT._serialized_start=231
  _RENDERCONTENTOUTPUT._serialized_end=286
  _RENDERSERVICE._serialized_start=289
  _RENDERSERVICE._serialized_end=428
# @@protoc_insertion_point(module_scope)



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.newsletter import newsletter_pb2 as _newsletter_pb2
from eolymp.wellknown import expression_pb2 as _expression_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateNewsletterInput(_message.Message):
    __slots__ = ["newsletter"]
    NEWSLETTER_FIELD_NUMBER: _ClassVar[int]
    newsletter: _newsletter_pb2.Newsletter
    def __init__(self, newsletter: _Optional[_Union[_newsletter_pb2.Newsletter, _Mapping]] = ...) -> None: ...

class CreateNewsletterOutput(_message.Message):
    __slots__ = ["newsletter_id"]
    NEWSLETTER_ID_FIELD_NUMBER: _ClassVar[int]
    newsletter_id: str
    def __init__(self, newsletter_id: _Optional[str] = ...) -> None: ...

class CreateNewsletterTranslationInput(_message.Message):
    __slots__ = ["newsletter_id", "translation"]
    NEWSLETTER_ID_FIELD_NUMBER: _ClassVar[int]
    TRANSLATION_FIELD_NUMBER: _ClassVar[int]
    newsletter_id: str
    translation: _newsletter_pb2.Newsletter.Translation
    def __init__(self, newsletter_id: _Optional[str] = ..., translation: _Optional[_Union[_newsletter_pb2.Newsletter.Translation, _Mapping]] = ...) -> None: ...

class CreateNewsletterTranslationOutput(_message.Message):
    __slots__ = ["translation_id"]
    TRANSLATION_ID_FIELD_NUMBER: _ClassVar[int]
    translation_id: str
    def __init__(self, translation_id: _Optional[str] = ...) -> None: ...

class DeleteNewsletterInput(_message.Message):
    __slots__ = ["newsletter_id"]
    NEWSLETTER_ID_FIELD_NUMBER: _ClassVar[int]
    newsletter_id: str
    def __init__(self, newsletter_id: _Optional[str] = ...) -> None: ...

class DeleteNewsletterOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DeleteNewsletterTranslationInput(_message.Message):
    __slots__ = ["newsletter_id", "translation_id"]
    NEWSLETTER_ID_FIELD_NUMBER: _ClassVar[int]
    TRANSLATION_ID_FIELD_NUMBER: _ClassVar[int]
    newsletter_id: str
    translation_id: str
    def __init__(self, newsletter_id: _Optional[str] = ..., translation_id: _Optional[str] = ...) -> None: ...

class DeleteNewsletterTranslationOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DescribeNewsletterInput(_message.Message):
    __slots__ = ["newsletter_id"]
    NEWSLETTER_ID_FIELD_NUMBER: _ClassVar[int]
    newsletter_id: str
    def __init__(self, newsletter_id: _Optional[str] = ...) -> None: ...

class DescribeNewsletterOutput(_message.Message):
    __slots__ = ["newsletter"]
    NEWSLETTER_FIELD_NUMBER: _ClassVar[int]
    newsletter: _newsletter_pb2.Newsletter
    def __init__(self, newsletter: _Optional[_Union[_newsletter_pb2.Newsletter, _Mapping]] = ...) -> None: ...

class DescribeNewsletterTranslationInput(_message.Message):
    __slots__ = ["newsletter_id", "translation_id"]
    NEWSLETTER_ID_FIELD_NUMBER: _ClassVar[int]
    TRANSLATION_ID_FIELD_NUMBER: _ClassVar[int]
    newsletter_id: str
    translation_id: str
    def __init__(self, newsletter_id: _Optional[str] = ..., translation_id: _Optional[str] = ...) -> None: ...

class DescribeNewsletterTranslationOutput(_message.Message):
    __slots__ = ["translation"]
    TRANSLATION_FIELD_NUMBER: _ClassVar[int]
    translation: _newsletter_pb2.Newsletter.Translation
    def __init__(self, translation: _Optional[_Union[_newsletter_pb2.Newsletter.Translation, _Mapping]] = ...) -> None: ...

class ListNewsletterTranslationsInput(_message.Message):
    __slots__ = ["filters", "newsletter_id", "offset", "size"]
    class Filter(_message.Message):
        __slots__ = ["id", "locale", "query"]
        ID_FIELD_NUMBER: _ClassVar[int]
        LOCALE_FIELD_NUMBER: _ClassVar[int]
        QUERY_FIELD_NUMBER: _ClassVar[int]
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        locale: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        query: str
        def __init__(self, query: _Optional[str] = ..., id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., locale: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ...) -> None: ...
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    NEWSLETTER_ID_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    filters: ListNewsletterTranslationsInput.Filter
    newsletter_id: str
    offset: int
    size: int
    def __init__(self, newsletter_id: _Optional[str] = ..., offset: _Optional[int] = ..., size: _Optional[int] = ..., filters: _Optional[_Union[ListNewsletterTranslationsInput.Filter, _Mapping]] = ...) -> None: ...

class ListNewsletterTranslationsOutput(_message.Message):
    __slots__ = ["items", "total"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_newsletter_pb2.Newsletter.Translation]
    total: int
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_newsletter_pb2.Newsletter.Translation, _Mapping]]] = ...) -> None: ...

class ListNewslettersInput(_message.Message):
    __slots__ = ["offset", "size"]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    offset: int
    size: int
    def __init__(self, offset: _Optional[int] = ..., size: _Optional[int] = ...) -> None: ...

class ListNewslettersOutput(_message.Message):
    __slots__ = ["items", "total"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_newsletter_pb2.Newsletter]
    total: int
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_newsletter_pb2.Newsletter, _Mapping]]] = ...) -> None: ...

class SendNewsletterInput(_message.Message):
    __slots__ = ["newsletter_id"]
    NEWSLETTER_ID_FIELD_NUMBER: _ClassVar[int]
    newsletter_id: str
    def __init__(self, newsletter_id: _Optional[str] = ...) -> None: ...

class SendNewsletterOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class TestNewsletterInput(_message.Message):
    __slots__ = ["email", "locale", "newsletter_id"]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    NEWSLETTER_ID_FIELD_NUMBER: _ClassVar[int]
    email: str
    locale: str
    newsletter_id: str
    def __init__(self, newsletter_id: _Optional[str] = ..., email: _Optional[str] = ..., locale: _Optional[str] = ...) -> None: ...

class TestNewsletterOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class UpdateNewsletterInput(_message.Message):
    __slots__ = ["newsletter", "newsletter_id", "patch"]
    class Patch(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    ALL: UpdateNewsletterInput.Patch
    CONTENT: UpdateNewsletterInput.Patch
    NEWSLETTER_FIELD_NUMBER: _ClassVar[int]
    NEWSLETTER_ID_FIELD_NUMBER: _ClassVar[int]
    PATCH_FIELD_NUMBER: _ClassVar[int]
    SUBJECT: UpdateNewsletterInput.Patch
    TYPE: UpdateNewsletterInput.Patch
    newsletter: _newsletter_pb2.Newsletter
    newsletter_id: str
    patch: _containers.RepeatedScalarFieldContainer[UpdateNewsletterInput.Patch]
    def __init__(self, patch: _Optional[_Iterable[_Union[UpdateNewsletterInput.Patch, str]]] = ..., newsletter_id: _Optional[str] = ..., newsletter: _Optional[_Union[_newsletter_pb2.Newsletter, _Mapping]] = ...) -> None: ...

class UpdateNewsletterOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class UpdateNewsletterTranslationInput(_message.Message):
    __slots__ = ["newsletter_id", "patch", "translation", "translation_id"]
    class Patch(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    ALL: UpdateNewsletterTranslationInput.Patch
    CONTENT: UpdateNewsletterTranslationInput.Patch
    LOCALE: UpdateNewsletterTranslationInput.Patch
    NEWSLETTER_ID_FIELD_NUMBER: _ClassVar[int]
    PATCH_FIELD_NUMBER: _ClassVar[int]
    SUBJECT: UpdateNewsletterTranslationInput.Patch
    TRANSLATION_FIELD_NUMBER: _ClassVar[int]
    TRANSLATION_ID_FIELD_NUMBER: _ClassVar[int]
    newsletter_id: str
    patch: _containers.RepeatedScalarFieldContainer[UpdateNewsletterTranslationInput.Patch]
    translation: _newsletter_pb2.Newsletter.Translation
    translation_id: str
    def __init__(self, patch: _Optional[_Iterable[_Union[UpdateNewsletterTranslationInput.Patch, str]]] = ..., newsletter_id: _Optional[str] = ..., translation_id: _Optional[str] = ..., translation: _Optional[_Union[_newsletter_pb2.Newsletter.Translation, _Mapping]] = ...) -> None: ...

class UpdateNewsletterTranslationOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class GetBookmarkInput(_message.Message):
    __slots__ = ["problem_id"]
    PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
    problem_id: str
    def __init__(self, problem_id: _Optional[str] = ...) -> None: ...

class GetBookmarkOutput(_message.Message):
    __slots__ = ["bookmark"]
    BOOKMARK_FIELD_NUMBER: _ClassVar[int]
    bookmark: bool
    def __init__(self, bookmark: bool = ...) -> None: ...

class SetBookmarkInput(_message.Message):
    __slots__ = ["bookmark", "problem_id"]
    BOOKMARK_FIELD_NUMBER: _ClassVar[int]
    PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
    bookmark: bool
    problem_id: str
    def __init__(self, problem_id: _Optional[str] = ..., bookmark: bool = ...) -> None: ...

class SetBookmarkOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/atlas/submission_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.atlas import submission_pb2 as eolymp_dot_atlas_dot_submission__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%eolymp/atlas/submission_service.proto\x12\x0c\x65olymp.atlas\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1d\x65olymp/atlas/submission.proto\x1a!eolymp/wellknown/expression.proto\"I\n\x15\x43reateSubmissionInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x0c\n\x04lang\x18\x02 \x01(\t\x12\x0e\n\x06source\x18\x03 \x01(\t\"/\n\x16\x43reateSubmissionOutput\x12\x15\n\rsubmission_id\x18\x01 \x01(\t\"D\n\x17\x44\x65scribeSubmissionInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x15\n\rsubmission_id\x18\x02 \x01(\t\"x\n\x18\x44\x65scribeSubmissionOutput\x12,\n\nsubmission\x18\x01 \x01(\x0b\x32\x18.eolymp.atlas.Submission\x12.\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1e.eolymp.atlas.Submission.Extra\"q\n\x14WatchSubmissionInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x15\n\rsubmission_id\x18\x02 \x01(\t\x12.\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1e.eolymp.atlas.Submission.Extra\"E\n\x15WatchSubmissionOutput\x12,\n\nsubmission\x18\x01 \x01(\x0b\x32\x18.eolymp.atlas.Submission\"Q\n\x15RetestSubmissionInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x15\n\rsubmission_id\x18\x02 \x01(\t\x12\r\n\x05\x64\x65\x62ug\x18\x03 \x01(\x08\"\x18\n\x16RetestSubmissionOutput\"\xd0\x05\n\x14ListSubmissionsInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\r\n\x05\x61\x66ter\x18\x0c \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12:\n\x07\x66ilters\x18( \x01(\x0b\x32).eolymp.atlas.ListSubmissionsInput.Filter\x12.\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1e.eolymp.atlas.Submission.Extra\x1a\x8a\x04\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x32\n\nproblem_id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12/\n\x07user_id\x18\x03 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x31\n\tmember_id\x18\t \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12;\n\x0csubmitted_at\x18\x04 \x03(\x0b\x32%.eolymp.wellknown.ExpressionTimestamp\x12\x31\n\x07runtime\x18\x05 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x30\n\x06status\x18\x06 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x31\n\x07verdict\x18\n \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x30\n\x05score\x18\x07 \x03(\x0b\x32!.eolymp.wellknown.ExpressionFloat\x12\x35\n\npercentage\x18\x08 \x03(\x0b\x32!.eolymp.wellknown.ExpressionFloat\"\x83\x01\n\x15ListSubmissionsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12\'\n\x05items\x18\x02 \x03(\x0b\x32\x18.eolymp.atlas.Submission\x12\x18\n\x10next_page_cursor\x18\x03 \x01(\t\x12\x18\n\x10prev_page_cursor\x18\x04 \x01(\t2\xc4\x06\n\x11SubmissionService\x12\xa0\x01\n\x10\x43reateSubmission\x12#.eolymp.atlas.CreateSubmissionInput\x1a$.eolymp.atlas.CreateSubmissionOutput\"A\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xe3\n\x1a\x8a\xe3\n\x16\x61tlas:submission:write\x82\xd3\xe4\x93\x02\x0e\"\x0c/submissions\x12\xb7\x01\n\x10RetestSubmission\x12#.eolymp.atlas.RetestSubmissionInput\x1a$.eolymp.atlas.RetestSubmissionOutput\"X\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xe3\n\x1a\x8a\xe3\n\x16\x61tlas:submission:write\x82\xd3\xe4\x93\x02%\"#/submissions/{submission_id}/retest\x12\xb5\x01\n\x12\x44\x65scribeSubmission\x12%.eolymp.atlas.DescribeSubmissionInput\x1a&.eolymp.atlas.DescribeSubmissionOutput\"P\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\n\x82\xe3\n\x19\x8a\xe3\n\x15\x61tlas:submission:read\x82\xd3\xe4\x93\x02\x1e\x12\x1c/submissions/{submission_id}\x12{\n\x0fWatchSubmission\x12\".eolymp.atlas.WatchSubmissionInput\x1a#.eolymp.atlas.WatchSubmissionOutput\"\x1d\x82\xe3\n\x19\x8a\xe3\n\x15\x61tlas:submission:read0\x01\x12\x9c\x01\n\x0fListSubmissions\x12\".eolymp.atlas.ListSubmissionsInput\x1a#.eolymp.atlas.ListSubmissionsOutput\"@\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\n\x82\xe3\n\x19\x8a\xe3\n\x15\x61tlas:submission:read\x82\xd3\xe4\x93\x02\x0e\x12\x0c/submissionsB-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.submission_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _SUBMISSIONSERVICE.methods_by_name['CreateSubmission']._options = None
  _SUBMISSIONSERVICE.methods_by_name['CreateSubmission']._serialized_options = b'\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\343\n\032\212\343\n\026atlas:submission:write\202\323\344\223\002\016\"\014/submissions'
  _SUBMISSIONSERVICE.methods_by_name['RetestSubmission']._options = None
  _SUBMISSIONSERVICE.methods_by_name['RetestSubmission']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\343\n\032\212\343\n\026atlas:submission:write\202\323\344\223\002%\"#/submissions/{submission_id}/retest'
  _SUBMISSIONSERVICE.methods_by_name['DescribeSubmission']._options = None
  _SUBMISSIONSERVICE.methods_by_name['DescribeSubmission']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\n\202\343\n\031\212\343\n\025atlas:submission:read\202\323\344\223\002\036\022\034/submissions/{submission_id}'
  _SUBMISSIONSERVICE.methods_by_name['WatchSubmission']._options = None
  _SUBMISSIONSERVICE.methods_by_name['WatchSubmission']._serialized_options = b'\202\343\n\031\212\343\n\025atlas:submission:read'
  _SUBMISSIONSERVICE.methods_by_name['ListSubmissions']._options = None
  _SUBMISSIONSERVICE.methods_by_name['ListSubmissions']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\n\202\343\n\031\212\343\n\025atlas:submission:read\202\323\344\223\002\016\022\014/submissions'
  _CREATESUBMISSIONINPUT._serialized_start=220
  _CREATESUBMISSIONINPUT._serialized_end=293
  _CREATESUBMISSIONOUTPUT._serialized_start=295
  _CREATESUBMISSIONOUTPUT._serialized_end=342
  _DESCRIBESUBMISSIONINPUT._serialized_start=344
  _DESCRIBESUBMISSIONINPUT._serialized_end=412
  _DESCRIBESUBMISSIONOUTPUT._serialized_start=414
  _DESCRIBESUBMISSIONOUTPUT._serialized_end=534
  _WATCHSUBMISSIONINPUT._serialized_start=536
  _WATCHSUBMISSIONINPUT._serialized_end=649
  _WATCHSUBMISSIONOUTPUT._serialized_start=651
  _WATCHSUBMISSIONOUTPUT._serialized_end=720
  _RETESTSUBMISSIONINPUT._serialized_start=722
  _RETESTSUBMISSIONINPUT._serialized_end=803
  _RETESTSUBMISSIONOUTPUT._serialized_start=805
  _RETESTSUBMISSIONOUTPUT._serialized_end=829
  _LISTSUBMISSIONSINPUT._serialized_start=832
  _LISTSUBMISSIONSINPUT._serialized_end=1552
  _LISTSUBMISSIONSINPUT_FILTER._serialized_start=1030
  _LISTSUBMISSIONSINPUT_FILTER._serialized_end=1552
  _LISTSUBMISSIONSOUTPUT._serialized_start=1555
  _LISTSUBMISSIONSOUTPUT._serialized_end=1686
  _SUBMISSIONSERVICE._serialized_start=1689
  _SUBMISSIONSERVICE._serialized_end=2525
# @@protoc_insertion_point(module_scope)



from eolymp.universe import quota_pb2 as _quota_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Space(_message.Message):
    __slots__ = ["affiliation", "graphql_url", "home_url", "id", "image", "issuer_url", "key", "name", "status", "subscription", "url", "visibility"]
    class Extra(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class Visibility(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class Subscription(_message.Message):
        __slots__ = ["billing_period_end", "billing_period_start", "plan", "quota", "quota_period_end", "quota_period_start", "seats"]
        BILLING_PERIOD_END_FIELD_NUMBER: _ClassVar[int]
        BILLING_PERIOD_START_FIELD_NUMBER: _ClassVar[int]
        PLAN_FIELD_NUMBER: _ClassVar[int]
        QUOTA_FIELD_NUMBER: _ClassVar[int]
        QUOTA_PERIOD_END_FIELD_NUMBER: _ClassVar[int]
        QUOTA_PERIOD_START_FIELD_NUMBER: _ClassVar[int]
        SEATS_FIELD_NUMBER: _ClassVar[int]
        billing_period_end: _timestamp_pb2.Timestamp
        billing_period_start: _timestamp_pb2.Timestamp
        plan: str
        quota: _quota_pb2.Quota
        quota_period_end: _timestamp_pb2.Timestamp
        quota_period_start: _timestamp_pb2.Timestamp
        seats: int
        def __init__(self, plan: _Optional[str] = ..., seats: _Optional[int] = ..., quota: _Optional[_Union[_quota_pb2.Quota, _Mapping]] = ..., billing_period_start: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., billing_period_end: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., quota_period_start: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., quota_period_end: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...
    ACTIVE: Space.Status
    AFFILIATION_FIELD_NUMBER: _ClassVar[int]
    GRAPHQL_URL_FIELD_NUMBER: _ClassVar[int]
    HOME_URL_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    IMAGE_FIELD_NUMBER: _ClassVar[int]
    ISSUER_URL_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    PRIVATE: Space.Visibility
    PUBLIC: Space.Visibility
    STATUS_FIELD_NUMBER: _ClassVar[int]
    SUBSCRIPTION: Space.Extra
    SUBSCRIPTION_FIELD_NUMBER: _ClassVar[int]
    SUSPENDED: Space.Status
    TRIAL: Space.Status
    UNKNOWN_EXTRA: Space.Extra
    UNKNOWN_STATUS: Space.Status
    UNKNOWN_VISIBILITY: Space.Visibility
    URL_FIELD_NUMBER: _ClassVar[int]
    VISIBILITY_FIELD_NUMBER: _ClassVar[int]
    affiliation: str
    graphql_url: str
    home_url: str
    id: str
    image: str
    issuer_url: str
    key: str
    name: str
    status: Space.Status
    subscription: Space.Subscription
    url: str
    visibility: Space.Visibility
    def __init__(self, id: _Optional[str] = ..., key: _Optional[str] = ..., url: _Optional[str] = ..., home_url: _Optional[str] = ..., issuer_url: _Optional[str] = ..., graphql_url: _Optional[str] = ..., name: _Optional[str] = ..., image: _Optional[str] = ..., visibility: _Optional[_Union[Space.Visibility, str]] = ..., status: _Optional[_Union[Space.Status, str]] = ..., subscription: _Optional[_Union[Space.Subscription, _Mapping]] = ..., affiliation: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/geography/geography.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.geography import country_pb2 as eolymp_dot_geography_dot_country__pb2
from eolymp.geography import region_pb2 as eolymp_dot_geography_dot_region__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n eolymp/geography/geography.proto\x12\x10\x65olymp.geography\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/geography/country.proto\x1a\x1d\x65olymp/geography/region.proto\x1a!eolymp/wellknown/expression.proto\"*\n\x14\x44\x65scribeCountryInput\x12\x12\n\ncountry_id\x18\x01 \x01(\t\"C\n\x15\x44\x65scribeCountryOutput\x12*\n\x07\x63ountry\x18\x01 \x01(\x0b\x32\x19.eolymp.geography.Country\"\xe7\x01\n\x12ListCountriesInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12<\n\x07\x66ilters\x18( \x01(\x0b\x32+.eolymp.geography.ListCountriesInput.Filter\x1au\n\x06\x46ilter\x12\r\n\x05query\x18\x01 \x01(\t\x12*\n\x02id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x04name\x18\x03 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\"N\n\x13ListCountriesOutput\x12(\n\x05items\x18\x01 \x03(\x0b\x32\x19.eolymp.geography.Country\x12\r\n\x05total\x18\x02 \x01(\x05\"(\n\x13\x44\x65scribeRegionInput\x12\x11\n\tregion_id\x18\x01 \x01(\t\"@\n\x14\x44\x65scribeRegionOutput\x12(\n\x06region\x18\x01 \x01(\x0b\x32\x18.eolymp.geography.Region\"\xac\x02\n\x10ListRegionsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12:\n\x07\x66ilters\x18( \x01(\x0b\x32).eolymp.geography.ListRegionsInput.Filter\x12\x12\n\ncountry_id\x18\x01 \x01(\t\x1a\xa9\x01\n\x06\x46ilter\x12\r\n\x05query\x18\x01 \x01(\t\x12*\n\x02id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x32\n\ncountry_id\x18\x03 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x04name\x18\x04 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\"K\n\x11ListRegionsOutput\x12\'\n\x05items\x18\x01 \x03(\x0b\x32\x18.eolymp.geography.Region\x12\r\n\x05total\x18\x02 \x01(\x05\x32\xfd\x05\n\tGeography\x12\x9d\x01\n\x0f\x44\x65scribeCountry\x12&.eolymp.geography.DescribeCountryInput\x1a\'.eolymp.geography.DescribeCountryOutput\"9\xea\xe2\n\x0c\xf5\xe2\n\x00\x00HB\xf8\xe2\n\xf4\x03\x82\xd3\xe4\x93\x02#\x12!/geography/countries/{country_id}\x12\x8a\x01\n\rListCountries\x12$.eolymp.geography.ListCountriesInput\x1a%.eolymp.geography.ListCountriesOutput\",\xea\xe2\n\x0c\xf5\xe2\n\x00\x00HB\xf8\xe2\n\xf4\x03\x82\xd3\xe4\x93\x02\x16\x12\x14/geography/countries\x12\x97\x01\n\x0e\x44\x65scribeRegion\x12%.eolymp.geography.DescribeRegionInput\x1a&.eolymp.geography.DescribeRegionOutput\"6\xea\xe2\n\x0c\xf5\xe2\n\x00\x00HB\xf8\xe2\n\xf4\x03\x82\xd3\xe4\x93\x02 \x12\x1e/geography/regions/{region_id}\x12\x82\x01\n\x0bListRegions\x12\".eolymp.geography.ListRegionsInput\x1a#.eolymp.geography.ListRegionsOutput\"*\xea\xe2\n\x0c\xf5\xe2\n\x00\x00HB\xf8\xe2\n\xf4\x03\x82\xd3\xe4\x93\x02\x14\x12\x12/geography/regions\x12\xa3\x01\n\x15\x44\x65precatedListRegions\x12\".eolymp.geography.ListRegionsInput\x1a#.eolymp.geography.ListRegionsOutput\"A\xea\xe2\n\x0c\xf5\xe2\n\x00\x00HB\xf8\xe2\n\xf4\x03\x82\xd3\xe4\x93\x02+\x12)/geography/countries/{country_id}/regionsB5Z3github.com/eolymp/go-sdk/eolymp/geography;geographyb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.geography.geography_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/geography;geography'
  _GEOGRAPHY.methods_by_name['DescribeCountry']._options = None
  _GEOGRAPHY.methods_by_name['DescribeCountry']._serialized_options = b'\352\342\n\014\365\342\n\000\000HB\370\342\n\364\003\202\323\344\223\002#\022!/geography/countries/{country_id}'
  _GEOGRAPHY.methods_by_name['ListCountries']._options = None
  _GEOGRAPHY.methods_by_name['ListCountries']._serialized_options = b'\352\342\n\014\365\342\n\000\000HB\370\342\n\364\003\202\323\344\223\002\026\022\024/geography/countries'
  _GEOGRAPHY.methods_by_name['DescribeRegion']._options = None
  _GEOGRAPHY.methods_by_name['DescribeRegion']._serialized_options = b'\352\342\n\014\365\342\n\000\000HB\370\342\n\364\003\202\323\344\223\002 \022\036/geography/regions/{region_id}'
  _GEOGRAPHY.methods_by_name['ListRegions']._options = None
  _GEOGRAPHY.methods_by_name['ListRegions']._serialized_options = b'\352\342\n\014\365\342\n\000\000HB\370\342\n\364\003\202\323\344\223\002\024\022\022/geography/regions'
  _GEOGRAPHY.methods_by_name['DeprecatedListRegions']._options = None
  _GEOGRAPHY.methods_by_name['DeprecatedListRegions']._serialized_options = b'\352\342\n\014\365\342\n\000\000HB\370\342\n\364\003\202\323\344\223\002+\022)/geography/countries/{country_id}/regions'
  _DESCRIBECOUNTRYINPUT._serialized_start=219
  _DESCRIBECOUNTRYINPUT._serialized_end=261
  _DESCRIBECOUNTRYOUTPUT._serialized_start=263
  _DESCRIBECOUNTRYOUTPUT._serialized_end=330
  _LISTCOUNTRIESINPUT._serialized_start=333
  _LISTCOUNTRIESINPUT._serialized_end=564
  _LISTCOUNTRIESINPUT_FILTER._serialized_start=447
  _LISTCOUNTRIESINPUT_FILTER._serialized_end=564
  _LISTCOUNTRIESOUTPUT._serialized_start=566
  _LISTCOUNTRIESOUTPUT._serialized_end=644
  _DESCRIBEREGIONINPUT._serialized_start=646
  _DESCRIBEREGIONINPUT._serialized_end=686
  _DESCRIBEREGIONOUTPUT._serialized_start=688
  _DESCRIBEREGIONOUTPUT._serialized_end=752
  _LISTREGIONSINPUT._serialized_start=755
  _LISTREGIONSINPUT._serialized_end=1055
  _LISTREGIONSINPUT_FILTER._serialized_start=886
  _LISTREGIONSINPUT_FILTER._serialized_end=1055
  _LISTREGIONSOUTPUT._serialized_start=1057
  _LISTREGIONSOUTPUT._serialized_end=1132
  _GEOGRAPHY._serialized_start=1135
  _GEOGRAPHY._serialized_end=1900
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/mailing/email_subscription_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.mailing import email_type_pb2 as eolymp_dot_mailing_dot_email__type__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/eolymp/mailing/email_subscription_service.proto\x12\x0e\x65olymp.mailing\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1f\x65olymp/mailing/email_type.proto\"/\n\x1e\x44\x65scribeEmailSubscriptionInput\x12\r\n\x05token\x18\x01 \x01(\t\"S\n\x1f\x44\x65scribeEmailSubscriptionOutput\x12\x30\n\rsubscriptions\x18\x01 \x03(\x0e\x32\x19.eolymp.mailing.EmailType\"_\n\x1cUpdateEmailSubscriptionInput\x12\r\n\x05token\x18\x01 \x01(\t\x12\x30\n\rsubscriptions\x18\x02 \x03(\x0e\x32\x19.eolymp.mailing.EmailType\"\x1f\n\x1dUpdateEmailSubscriptionOutput2\xea\x02\n\x18\x45mailSubscriptionService\x12\xa8\x01\n\x19\x44\x65scribeEmailSubscription\x12..eolymp.mailing.DescribeEmailSubscriptionInput\x1a/.eolymp.mailing.DescribeEmailSubscriptionOutput\"*\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x15\x12\x13/email-subscription\x12\xa2\x01\n\x17UpdateEmailSubscription\x12,.eolymp.mailing.UpdateEmailSubscriptionInput\x1a-.eolymp.mailing.UpdateEmailSubscriptionOutput\"*\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x15\"\x13/email-subscriptionB1Z/github.com/eolymp/go-sdk/eolymp/mailing;mailingb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.mailing.email_subscription_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z/github.com/eolymp/go-sdk/eolymp/mailing;mailing'
  _EMAILSUBSCRIPTIONSERVICE.methods_by_name['DescribeEmailSubscription']._options = None
  _EMAILSUBSCRIPTIONSERVICE.methods_by_name['DescribeEmailSubscription']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\025\022\023/email-subscription'
  _EMAILSUBSCRIPTIONSERVICE.methods_by_name['UpdateEmailSubscription']._options = None
  _EMAILSUBSCRIPTIONSERVICE.methods_by_name['UpdateEmailSubscription']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\025\"\023/email-subscription'
  _DESCRIBEEMAILSUBSCRIPTIONINPUT._serialized_start=167
  _DESCRIBEEMAILSUBSCRIPTIONINPUT._serialized_end=214
  _DESCRIBEEMAILSUBSCRIPTIONOUTPUT._serialized_start=216
  _DESCRIBEEMAILSUBSCRIPTIONOUTPUT._serialized_end=299
  _UPDATEEMAILSUBSCRIPTIONINPUT._serialized_start=301
  _UPDATEEMAILSUBSCRIPTIONINPUT._serialized_end=396
  _UPDATEEMAILSUBSCRIPTIONOUTPUT._serialized_start=398
  _UPDATEEMAILSUBSCRIPTIONOUTPUT._serialized_end=429
  _EMAILSUBSCRIPTIONSERVICE._serialized_start=432
  _EMAILSUBSCRIPTIONSERVICE._serialized_end=794
# @@protoc_insertion_point(module_scope)



from .enum_value_pb2 import *
from .institution_service_http import *
from .enum_pb2 import *
from .enum_service_pb2 import *
from .geography_region_pb2 import *
from .enum_service_http import *
from .geography_service_pb2 import *
from .institution_service_pb2 import *
from .geography_service_http import *
from .geography_country_pb2 import *
from .institution_pb2 import *



from .universe_http import *
from .plan_pb2 import *
from .space_service_pb2 import *
from .quota_pb2 import *
from .space_service_http import *
from .space_pb2 import *
from .events_pb2 import *
from .billing_pb2 import *
from .plan_service_pb2 import *
from .universe_pb2 import *
from .plan_service_http import *
from .billing_service_http import *
from .billing_service_pb2 import *



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/course/module_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.course import module_pb2 as eolymp_dot_course_dot_module__pb2
from eolymp.wellknown import direction_pb2 as eolymp_dot_wellknown_dot_direction__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"eolymp/course/module_service.proto\x12\reolymp.course\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1a\x65olymp/course/module.proto\x1a eolymp/wellknown/direction.proto\x1a!eolymp/wellknown/expression.proto\x1a\x1fgoogle/protobuf/timestamp.proto\":\n\x11\x43reateModuleInput\x12%\n\x06module\x18\x01 \x01(\x0b\x32\x15.eolymp.course.Module\"\'\n\x12\x43reateModuleOutput\x12\x11\n\tmodule_id\x18\x01 \x01(\t\"\xe1\x01\n\x11UpdateModuleInput\x12\x35\n\x05patch\x18\x01 \x03(\x0e\x32&.eolymp.course.UpdateModuleInput.Patch\x12\x11\n\tmodule_id\x18\x02 \x01(\t\x12%\n\x06module\x18\x03 \x01(\x0b\x32\x15.eolymp.course.Module\"[\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\t\n\x05\x44RAFT\x10\x01\x12\t\n\x05\x45XTRA\x10\x06\x12\x08\n\x04NAME\x10\x02\x12\r\n\tIMAGE_URL\x10\x03\x12\t\n\x05INDEX\x10\x04\x12\x0f\n\x0b\x44\x45SCRIPTION\x10\x05\"\x14\n\x12UpdateModuleOutput\"&\n\x11\x44\x65leteModuleInput\x12\x11\n\tmodule_id\x18\x01 \x01(\t\"\x14\n\x12\x44\x65leteModuleOutput\"i\n\x13\x44\x65scribeModuleInput\x12\x11\n\tmodule_id\x18\x01 \x01(\t\x12\x12\n\nstudent_id\x18\x02 \x01(\t\x12+\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1b.eolymp.course.Module.Extra\"=\n\x14\x44\x65scribeModuleOutput\x12%\n\x06module\x18\x01 \x01(\x0b\x32\x15.eolymp.course.Module\"\x98\x03\n\x10ListModulesInput\x12\x12\n\nstudent_id\x18\x05 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x37\n\x07\x66ilters\x18( \x01(\x0b\x32&.eolymp.course.ListModulesInput.Filter\x12\x32\n\x04sort\x18\x32 \x01(\x0e\x32$.eolymp.course.ListModulesInput.Sort\x12*\n\x05order\x18\x33 \x01(\x0e\x32\x1b.eolymp.wellknown.Direction\x12+\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1b.eolymp.course.Module.Extra\x1ay\n\x06\x46ilter\x12\r\n\x05query\x18\x01 \x01(\t\x12/\n\x05\x64raft\x18\x02 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12/\n\x05\x65xtra\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\"\x11\n\x04Sort\x12\t\n\x05INDEX\x10\x00\"H\n\x11ListModulesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12$\n\x05items\x18\x02 \x03(\x0b\x32\x15.eolymp.course.Module\"%\n\x10StartModuleInput\x12\x11\n\tmodule_id\x18\x01 \x01(\t\"\x13\n\x11StartModuleOutput\"\xb1\x01\n\x11\x41ssignModuleInput\x12\x11\n\tmember_id\x18\x01 \x01(\t\x12\x11\n\tmodule_id\x18\x02 \x01(\t\x12/\n\x0bstart_after\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x33\n\x0f\x63omplete_before\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x08\x64uration\x18\r \x01(\r\"\x14\n\x12\x41ssignModuleOutput\";\n\x13UnassignModuleInput\x12\x11\n\tmember_id\x18\x01 \x01(\t\x12\x11\n\tmodule_id\x18\x02 \x01(\t\"\x16\n\x14UnassignModuleOutput2\xa0\n\n\rModuleService\x12\x8f\x01\n\x0c\x43reateModule\x12 .eolymp.course.CreateModuleInput\x1a!.eolymp.course.CreateModuleOutput\":\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\n\x1a\x08/modules\x12\x9b\x01\n\x0cUpdateModule\x12 .eolymp.course.UpdateModuleInput\x1a!.eolymp.course.UpdateModuleOutput\"F\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x16\x1a\x14/modules/{module_id}\x12\x9b\x01\n\x0c\x44\x65leteModule\x12 .eolymp.course.DeleteModuleInput\x1a!.eolymp.course.DeleteModuleOutput\"F\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x16*\x14/modules/{module_id}\x12\xa0\x01\n\x0e\x44\x65scribeModule\x12\".eolymp.course.DescribeModuleInput\x1a#.eolymp.course.DescribeModuleOutput\"E\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x16\x12\x14/modules/{module_id}\x12\x8b\x01\n\x0bListModules\x12\x1f.eolymp.course.ListModulesInput\x1a .eolymp.course.ListModulesOutput\"9\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\n\x12\x08/modules\x12\x9d\x01\n\x0bStartModule\x12\x1f.eolymp.course.StartModuleInput\x1a .eolymp.course.StartModuleOutput\"K\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x1c\"\x1a/modules/{module_id}/start\x12\xb3\x01\n\x0c\x41ssignModule\x12 .eolymp.course.AssignModuleInput\x1a!.eolymp.course.AssignModuleOutput\"^\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02.\x1a,/modules/{module_id}/assignments/{member_id}\x12\xb9\x01\n\x0eUnassignModule\x12\".eolymp.course.UnassignModuleInput\x1a#.eolymp.course.UnassignModuleOutput\"^\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02.*,/modules/{module_id}/assignments/{member_id}B/Z-github.com/eolymp/go-sdk/eolymp/course;courseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.course.module_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/course;course'
  _MODULESERVICE.methods_by_name['CreateModule']._options = None
  _MODULESERVICE.methods_by_name['CreateModule']._serialized_options = b'\202\343\n\027\212\343\n\023course:course:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\n\032\010/modules'
  _MODULESERVICE.methods_by_name['UpdateModule']._options = None
  _MODULESERVICE.methods_by_name['UpdateModule']._serialized_options = b'\202\343\n\027\212\343\n\023course:course:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\026\032\024/modules/{module_id}'
  _MODULESERVICE.methods_by_name['DeleteModule']._options = None
  _MODULESERVICE.methods_by_name['DeleteModule']._serialized_options = b'\202\343\n\027\212\343\n\023course:course:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\026*\024/modules/{module_id}'
  _MODULESERVICE.methods_by_name['DescribeModule']._options = None
  _MODULESERVICE.methods_by_name['DescribeModule']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\026\022\024/modules/{module_id}'
  _MODULESERVICE.methods_by_name['ListModules']._options = None
  _MODULESERVICE.methods_by_name['ListModules']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\n\022\010/modules'
  _MODULESERVICE.methods_by_name['StartModule']._options = None
  _MODULESERVICE.methods_by_name['StartModule']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\034\"\032/modules/{module_id}/start'
  _MODULESERVICE.methods_by_name['AssignModule']._options = None
  _MODULESERVICE.methods_by_name['AssignModule']._serialized_options = b'\202\343\n\027\212\343\n\023course:course:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002.\032,/modules/{module_id}/assignments/{member_id}'
  _MODULESERVICE.methods_by_name['UnassignModule']._options = None
  _MODULESERVICE.methods_by_name['UnassignModule']._serialized_options = b'\202\343\n\027\212\343\n\023course:course:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002.*,/modules/{module_id}/assignments/{member_id}'
  _CREATEMODULEINPUT._serialized_start=282
  _CREATEMODULEINPUT._serialized_end=340
  _CREATEMODULEOUTPUT._serialized_start=342
  _CREATEMODULEOUTPUT._serialized_end=381
  _UPDATEMODULEINPUT._serialized_start=384
  _UPDATEMODULEINPUT._serialized_end=609
  _UPDATEMODULEINPUT_PATCH._serialized_start=518
  _UPDATEMODULEINPUT_PATCH._serialized_end=609
  _UPDATEMODULEOUTPUT._serialized_start=611
  _UPDATEMODULEOUTPUT._serialized_end=631
  _DELETEMODULEINPUT._serialized_start=633
  _DELETEMODULEINPUT._serialized_end=671
  _DELETEMODULEOUTPUT._serialized_start=673
  _DELETEMODULEOUTPUT._serialized_end=693
  _DESCRIBEMODULEINPUT._serialized_start=695
  _DESCRIBEMODULEINPUT._serialized_end=800
  _DESCRIBEMODULEOUTPUT._serialized_start=802
  _DESCRIBEMODULEOUTPUT._serialized_end=863
  _LISTMODULESINPUT._serialized_start=866
  _LISTMODULESINPUT._serialized_end=1274
  _LISTMODULESINPUT_FILTER._serialized_start=1134
  _LISTMODULESINPUT_FILTER._serialized_end=1255
  _LISTMODULESINPUT_SORT._serialized_start=1257
  _LISTMODULESINPUT_SORT._serialized_end=1274
  _LISTMODULESOUTPUT._serialized_start=1276
  _LISTMODULESOUTPUT._serialized_end=1348
  _STARTMODULEINPUT._serialized_start=1350
  _STARTMODULEINPUT._serialized_end=1387
  _STARTMODULEOUTPUT._serialized_start=1389
  _STARTMODULEOUTPUT._serialized_end=1408
  _ASSIGNMODULEINPUT._serialized_start=1411
  _ASSIGNMODULEINPUT._serialized_end=1588
  _ASSIGNMODULEOUTPUT._serialized_start=1590
  _ASSIGNMODULEOUTPUT._serialized_end=1610
  _UNASSIGNMODULEINPUT._serialized_start=1612
  _UNASSIGNMODULEINPUT._serialized_end=1671
  _UNASSIGNMODULEOUTPUT._serialized_start=1673
  _UNASSIGNMODULEOUTPUT._serialized_end=1695
  _MODULESERVICE._serialized_start=1698
  _MODULESERVICE._serialized_end=3010
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Address(_message.Message):
    __slots__ = ["city", "country", "line1", "line2", "postal_code", "state"]
    CITY_FIELD_NUMBER: _ClassVar[int]
    COUNTRY_FIELD_NUMBER: _ClassVar[int]
    LINE1_FIELD_NUMBER: _ClassVar[int]
    LINE2_FIELD_NUMBER: _ClassVar[int]
    POSTAL_CODE_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    city: str
    country: str
    line1: str
    line2: str
    postal_code: str
    state: str
    def __init__(self, country: _Optional[str] = ..., state: _Optional[str] = ..., postal_code: _Optional[str] = ..., city: _Optional[str] = ..., line1: _Optional[str] = ..., line2: _Optional[str] = ...) -> None: ...



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.taxonomy import institution_pb2 as _institution_pb2
from eolymp.wellknown import expression_pb2 as _expression_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DescribeInstitutionInput(_message.Message):
    __slots__ = ["institution_id"]
    INSTITUTION_ID_FIELD_NUMBER: _ClassVar[int]
    institution_id: str
    def __init__(self, institution_id: _Optional[str] = ...) -> None: ...

class DescribeInstitutionOutput(_message.Message):
    __slots__ = ["institution"]
    INSTITUTION_FIELD_NUMBER: _ClassVar[int]
    institution: _institution_pb2.Institution
    def __init__(self, institution: _Optional[_Union[_institution_pb2.Institution, _Mapping]] = ...) -> None: ...

class ListInstitutionsInput(_message.Message):
    __slots__ = ["filters", "offset", "size"]
    class Filter(_message.Message):
        __slots__ = ["acronym", "country_id", "governance", "id", "level", "name", "query", "region_id", "type"]
        ACRONYM_FIELD_NUMBER: _ClassVar[int]
        COUNTRY_ID_FIELD_NUMBER: _ClassVar[int]
        GOVERNANCE_FIELD_NUMBER: _ClassVar[int]
        ID_FIELD_NUMBER: _ClassVar[int]
        LEVEL_FIELD_NUMBER: _ClassVar[int]
        NAME_FIELD_NUMBER: _ClassVar[int]
        QUERY_FIELD_NUMBER: _ClassVar[int]
        REGION_ID_FIELD_NUMBER: _ClassVar[int]
        TYPE_FIELD_NUMBER: _ClassVar[int]
        acronym: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionString]
        country_id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        governance: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        level: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        name: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionString]
        query: str
        region_id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        type: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        def __init__(self, query: _Optional[str] = ..., id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., name: _Optional[_Iterable[_Union[_expression_pb2.ExpressionString, _Mapping]]] = ..., acronym: _Optional[_Iterable[_Union[_expression_pb2.ExpressionString, _Mapping]]] = ..., country_id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., region_id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., level: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ..., type: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ..., governance: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ...) -> None: ...
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    filters: ListInstitutionsInput.Filter
    offset: int
    size: int
    def __init__(self, offset: _Optional[int] = ..., size: _Optional[int] = ..., filters: _Optional[_Union[ListInstitutionsInput.Filter, _Mapping]] = ...) -> None: ...

class ListInstitutionsOutput(_message.Message):
    __slots__ = ["items", "total"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_institution_pb2.Institution]
    total: int
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_institution_pb2.Institution, _Mapping]]] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Problem(_message.Message):
    __slots__ = ["acceptance_rate", "constraints", "difficulty", "id", "links", "number", "origin", "private", "submissions_accepted", "submissions_count", "topics", "url", "visible", "vote", "vote_count"]
    class Extra(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class Constraints(_message.Message):
        __slots__ = ["cpu_limit_max", "cpu_limit_min", "memory_limit_max", "memory_limit_min", "time_limit_max", "time_limit_min"]
        CPU_LIMIT_MAX_FIELD_NUMBER: _ClassVar[int]
        CPU_LIMIT_MIN_FIELD_NUMBER: _ClassVar[int]
        MEMORY_LIMIT_MAX_FIELD_NUMBER: _ClassVar[int]
        MEMORY_LIMIT_MIN_FIELD_NUMBER: _ClassVar[int]
        TIME_LIMIT_MAX_FIELD_NUMBER: _ClassVar[int]
        TIME_LIMIT_MIN_FIELD_NUMBER: _ClassVar[int]
        cpu_limit_max: int
        cpu_limit_min: int
        memory_limit_max: int
        memory_limit_min: int
        time_limit_max: int
        time_limit_min: int
        def __init__(self, time_limit_min: _Optional[int] = ..., time_limit_max: _Optional[int] = ..., cpu_limit_min: _Optional[int] = ..., cpu_limit_max: _Optional[int] = ..., memory_limit_min: _Optional[int] = ..., memory_limit_max: _Optional[int] = ...) -> None: ...
    class LinksEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    ACCEPTANCE_RATE_FIELD_NUMBER: _ClassVar[int]
    CONSTRAINTS_FIELD_NUMBER: _ClassVar[int]
    DIFFICULTY_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    LINKS_FIELD_NUMBER: _ClassVar[int]
    NUMBER_FIELD_NUMBER: _ClassVar[int]
    ORIGIN_FIELD_NUMBER: _ClassVar[int]
    PRIVATE_FIELD_NUMBER: _ClassVar[int]
    SUBMISSIONS_ACCEPTED_FIELD_NUMBER: _ClassVar[int]
    SUBMISSIONS_COUNT_FIELD_NUMBER: _ClassVar[int]
    TOPICS_FIELD_NUMBER: _ClassVar[int]
    UNKNOWN_EXTRA: Problem.Extra
    URL_FIELD_NUMBER: _ClassVar[int]
    VISIBLE_FIELD_NUMBER: _ClassVar[int]
    VOTE: Problem.Extra
    VOTE_COUNT_FIELD_NUMBER: _ClassVar[int]
    VOTE_FIELD_NUMBER: _ClassVar[int]
    acceptance_rate: float
    constraints: Problem.Constraints
    difficulty: int
    id: str
    links: _containers.ScalarMap[str, str]
    number: int
    origin: str
    private: bool
    submissions_accepted: int
    submissions_count: int
    topics: _containers.RepeatedScalarFieldContainer[str]
    url: str
    visible: bool
    vote: int
    vote_count: int
    def __init__(self, id: _Optional[str] = ..., url: _Optional[str] = ..., links: _Optional[_Mapping[str, str]] = ..., number: _Optional[int] = ..., visible: bool = ..., private: bool = ..., origin: _Optional[str] = ..., topics: _Optional[_Iterable[str]] = ..., constraints: _Optional[_Union[Problem.Constraints, _Mapping]] = ..., acceptance_rate: _Optional[float] = ..., submissions_count: _Optional[int] = ..., submissions_accepted: _Optional[int] = ..., vote: _Optional[int] = ..., vote_count: _Optional[int] = ..., difficulty: _Optional[int] = ...) -> None: ...



from .submission_pb2 import *
from .submission_service_http import *
from .testing_service_pb2 import *
from .script_pb2 import *
from .statement_pb2 import *
from .attachment_service_http import *
from .code_template_pb2 import *
from .editorial_pb2 import *
from .snapshot_pb2 import *
from .atlas_pb2 import *
from .attachment_service_pb2 import *
from .checker_pb2 import *
from .attachment_pb2 import *
from .interactor_pb2 import *
from .script_service_pb2 import *
from .problem_pb2 import *
from .code_template_service_http import *
from .code_template_service_pb2 import *
from .events_pb2 import *
from .testing_config_pb2 import *
from .testing_service_http import *
from .problem_service_pb2 import *
from .testing_feedback_pb2 import *
from .solution_service_pb2 import *
from .version_pb2 import *
from .suggestion_service_pb2 import *
from .suggestion_service_http import *
from .testing_test_pb2 import *
from .scoring_service_pb2 import *
from .script_service_http import *
from .testing_scoring_pb2 import *
from .editorial_service_pb2 import *
from .configuration_service_pb2 import *
from .testing_testset_pb2 import *
from .configuration_service_http import *
from .editorial_service_http import *
from .atlas_http import *
from .statement_service_http import *
from .solution_pb2 import *
from .scoring_score_pb2 import *
from .statement_service_pb2 import *
from .bookmark_service_http import *
from .bookmark_service_pb2 import *
from .problem_service_http import *
from .solution_service_http import *
from .suggestion_pb2 import *
from .submission_service_pb2 import *
from .scoring_service_http import *
